% This file is used to parse submodel equations.
% It replaces binding polynomials and dissociation constants with the 
% correct variables.

function [Equations_out] = IndexPHMK_alternate(Equations_in,SVarList, kName)   
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.

delimiters = '.<>!@''\/*+-%$#@&^()[]{}|`~;= ';

Equations_out = [];

b = 1;
% For every equation
while b <= length( Equations_in )
    Equations_out{b} = '';
    % Loop until there is no text left in the input field
    while( length( Equations_in{b} ) > 0 )
    
        % Loop until a word that is not a delimiter is found
        % of course, check whether there is even text in the input
        % and whether we haven't run past the end of the line
        a = 1;              
        if isempty( Equations_in{b} )
            break;
        else
            while( a < length( Equations_in{b} ) + 1 )
                if ~ismember( Equations_in{b}(a), delimiters )
                    break;
                end
                a = a + 1;
            end
        end
        
        % if we skipped past delimiters copy them to the output
        if ( a - 1 ) > 0            
            Equations_out{b} = [ Equations_out{b} Equations_in{b}(1 : a - 1 ) ];
        end

        % Grab a word from the list, and remove it from the list of things
        % to do. Basically the 'used' input gets chopped from the start.
        [ token Equations_in{b} ] = strtok(Equations_in{b}, delimiters );
    
        % If the word starts with P_ Km_ Kh_ or Kk_ then it is of interest
        % and warrants further investigation
        if length( token ) > 2
            if strcmp( token( 1 : 2 ), 'P_' )
                p = strcmp( token( 3:length(token) ), SVarList );
                if sum( p ) > 0
                    token = sprintf( 'P(%d)', find( p == 1 ) );
                end
            end
        end
    
        if length( token ) > 3
            tmp = token( 1 : 3 );
            % check for tokens Km Kh Kk and so forth
            if max( strcmp(tmp, strcat('K', kName, '_') ) )
                q = strcmp( token( 4:length(token) ), SVarList );
    
                if sum(q) > 0                    
                    for a = 1 : length( kName )
                        if tmp == strcat('K', kName{a}, '_')
                            token = sprintf( ['K' kName{a} '(%d)'], find( q == 1 ) );
                        end
                    end
                end
            end
        end
        Equations_out{b} = [ Equations_out{b} token ];
    end
    b = b + 1;    
end