function [ReactantList,StoichArray,FluxEquations,BoundIonStoichArray] = ...
    ReadReactionEntry(Abbrv,ModelName,ReactionStoich,comp_name);
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.

try
    F = textread(strcat(Abbrv,'.txt'),'%s');
catch
    disp( sprintf( 'File %s.txt not found!', Abbrv ) );
    return;
end

%% Preserve linebreaks
% Generate a list exactly the same as the input file
% but with a ` where the linebreaks used to be'delimiter', '`');
tmp = textread(strcat(Abbrv,'.txt'),'%s', 'endofline', '`', 'delimiter', '`' , 'bufsize', 200000);
% add marks for linebreaks
tmp = regexprep( tmp, '\r', '`\r' );
tmp = regexprep( tmp, '\n', '`\n' );
tmp = regexprep( tmp, '`\r`\n', '`\r\n' );
G = textscan( char(tmp(1)), '%s' );

% find the empty lines and remove them
indices = find( strcmp( G{1}, '`' ) == 1 );
G{1}(indices) = [];

N = length(F);

%% Define model file keywords
keywords{1} = 'model';
keywords{2} = 'EOF';
keywords{3} = 'allosteric_reactants';
keywords{4} = 'equations';

%% Getting ReactantList and StoichArray
% convert ReactionStoich to cellarray
ReactionStoich = str2array(ReactionStoich);
Nr = 0;
for i = 1:length(ReactionStoich)
  if (~(strcmp(ReactionStoich(i),'+')||strcmp(ReactionStoich(i),'=')))... 
        && isempty(str2num(char(ReactionStoich(i))))
    Nr = Nr + 1; % number of reactants
    ReactantList{Nr} = ReactionStoich{i};
  end
end

StoichArray = zeros(length(ReactantList),1);
si = -1;
n = 1; % default stoichiometry
for i = 1:length(ReactionStoich)
  if ~isempty(str2num(char(ReactionStoich(i))))
    n = str2num(char(ReactionStoich(i))); % non-default stoichiometry
  end
  if strcmp(ReactionStoich(i),'=')
    si = +1; % switch to right-side of equation
  end
  if (~(strcmp(ReactionStoich(i),'+')||strcmp(ReactionStoich(i),'='))) ...
          && isempty(str2num(char(ReactionStoich(i))))
    [v,j] = max( strcmp(ReactionStoich(i),ReactantList) );
    StoichArray(j) = StoichArray(j) + si*n; % edited by Joep to add rather than equate
    n = 1; % reset to default stoichiometry
  end
end

%% Process file
mflag = 0; % flag for identification model
ja_start = 0;
i = 0;
while i < N;
  i = i+1;
  if strcmp(F(i),'model')
    i = i + 1; 
    if strcmp(F(i),ModelName)
      mflag = 1;
      while (~sum(strcmp(F(i),{'allosteric_reactants', 'equations'})))&&(i<N)
        i = i+1;
      end
      if strcmp(F(i),'allosteric_reactants')
        i = i + 1;
        ja_start = i;
        while (~sum(strcmp(F(i),keywords)))&&(i<N)
          i = i+1;
        end
        ja_end = i-1;
      end
      if ja_start
        Na = 1 + ja_end-ja_start; % number of allosteric reactants
      else
        Na = 0;
      end

      if strcmp(F(i),'equations')
        i = i + 1;
        je_start = i;
        while (~sum(strcmp(F(i),keywords)))&&(i<N)
          i = i+1;
        end
        je_end = i-1;
      end
    end
    
  end
  
end

if mflag == 0
  warning = nomodel(Abbrv,ModelName)
end

if ~exist( 'je_start' )
  error( sprintf( 'Cannot find equations keyword in %s!', Abbrv) );
  return;
end

%% Write the submodel equations
space = '';
if mflag
  ii = 1;
  FluxEquations{ii} = '';
  for i = je_start:je_end;
    current_word = char(F(i));
    FluxEquations{ii} = strcat( FluxEquations{ii}, [ space char(F(i)) ] );
    if ( strcmp( G{1}{i}(end), '`' ) || strcmp(current_word(end),';') ) && (i ~= je_end);
      ii = ii+1;
      space = '';
      FluxEquations{ii} = '';
    end
 end
end

if ~mflag
  FluxEquations = {};
end

if Na
  Nr = Nr + Na;
  for j = ja_start:ja_end
    ReactantList = [ReactantList F(j)];
    StoichArray = [StoichArray' 0]';
  end
end

%% Searching for and replacing Keq with Keq_{Abbrv} in FluxEquations

for i = 1:length(FluxEquations)
  characters = char(FluxEquations{i});
  istart = []; % list of start indexes of 'unspecified's
  j = 1; 
  while j <= length(characters)-2
    if strcmp(characters(j:j+2),'Keq')
      istart = [istart j];
    end
    j = j+1;
  end
  % Concatenate the equation script
  if isempty(istart)
    eq = characters;
  else
    eq = characters(1:istart(1)+2);
    for j = 1:(length(istart)-1)
      eq = strcat(eq,'_',Abbrv,'_',comp_name,characters(istart(j)+3:istart(j+1)+2) ); 
    end
    eq = strcat(eq,'_',Abbrv,'_',comp_name,characters(istart(end)+3:end));
  end
  FluxEquations{i} = char(eq);
end

%% Searching for and replacing J with J_{Abbrv} in FluxEquations

for i = 1:length(FluxEquations)
  characters = char(FluxEquations{i});
  istart = []; % list of start indexes of 'unspecified's
  j = 1; 
  while j <= length(characters)-2
    if strcmp(characters(j:j+1),'J=')
      istart = [istart j];
    end
    if strcmp(characters(j:j+2),'J =')
      istart = [istart j];
    end
    j = j+1;
  end
  % Concatenate the equation script
  if isempty(istart)
    eq = characters;
  else
    eq = characters(1:istart(1));
    for j = 1:(length(istart)-1)
      eq = strcat(eq,'_',Abbrv,'_',comp_name,characters(istart(j)+1:istart(j+1)+1) ); 
    end
    eq = strcat(eq,'_',Abbrv,'_',comp_name,characters(istart(end)+1:end));
  end
  FluxEquations{i} = char(eq);
end
