% This function converts enthalpy values to different ionic strengths
%
% enthalpy = changeIonicStrengthEnthalpy( Enthalpy_old, charge, ...
%                                         ionCharge, I_old, I_new )
%
% Where
%    Enthalpy_old  -   old H value
%    Enthalpy_new  -   new H value
%    charge        -   Charge of unbound form
%    ionCharge     -   Charge of ion
%    I_old         -   Old ionic strength
%    I_new         -   New ionic strength
%    T             -   Temperature

function enthalpy_new = changeIonicStrengthEnthalpy( enthalpy_in, charge, ...
                                               ionCharge, I_old, I_new, T )
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.
                                           
    % Calculate charge factor
    z = ( ionCharge^2 + charge^2 ) - ( charge + ionCharge )^2; 

    alpha_H = -1.28466e-5 * T^2 + 9.90399e-8 * T^3;
    P = I_new^0.5;
    R = I_old^0.5;    
    h = ( P / ( 1 + 1.6 * P ) - R / ( 1 + 1.6 * R ) );
    
    beta_H2 = alpha_H * h; 
    
    % Ionic strength correction for enthalpy
    enthalpy = enthalpy_in + beta_H2 * z