% This function converts Gibbs energy of formation values to different ionic strengths
%
% gibbs_new = changeIonicStrength( Gibbs_old, charge, ionCharge, I_old, I_new )
%
% Where
%    gibbs_old     -   old G value
%    gibbs_new     -   new G value
%    charge        -   Charge of unbound form
%    ionCharge     -   Charge of ion
%    I_old         -   Old ionic strength
%    I_new         -   New ionic strength
%    T             -   Temperature

% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.

    RTalpha = 9.20483e-3 * T - 1.28467e-5 * T^2 + 4.95199e-8 * T^3; 
    P = I_new^0.5;
    Q = I_old^0.5;    
    f = ( P / ( 1 + 1.6 * P ) - Q / ( 1 + 1.6 * Q ) );
    
    beta_G = RTalpha * f; 
    
    % Ionic strength correction for gibbs energy
    gibbs_new = gibbs_in - beta_G * ( charge^2 - nH );