% This function converts pKa values to different ionic strengths
%
% pKa = changeIonicStrength( pKa_old, charge, ionCharge, I_old, I_new )
%
% Where
%    pKa_old    -   old pKa value
%    pKa_new    -   new pKa value
%    charge     -   Charge of unbound form
%    ionCharge  -   Charge of ion
%    I_old      -   Old ionic strength
%    I_new      -   New ionic strength
%    T          -   Temperature

function pKa = changeIonicStrength( pKa_in, charge, ionCharge, I_old, I_new, T )
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.

    % Calculate charge factor
    z = ( ionCharge^2 + charge^2 ) - ( charge + ionCharge )^2; 

    alpha_K = 1.10708 - 1.54508e-3 * T + 5.95584e-6 * T^2;
    P = I_new^0.5;
    R = I_old^0.5;    
    g = ( R / ( 1 + 1.6 * R ) - P / ( 1 + 1.6 * P ) );
    beta_K = (alpha_K/2.303) * g;
    
    % Ionic strength correction for pka
    pKa = pKa_in + beta_K * z;