function [ beta_K, beta_G, beta_H, beta_H2 ] = getIonicStrengthCorrectionFactors( ...
    T, I_tabulated_reactants, I_tabulated_pKa, I_new )
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.

[ alpha_K, RTalpha, alpha_H ] = getAlphas( T );

P = I_new^0.5;
Q = I_tabulated_reactants^0.5;
R = I_tabulated_pKa^0.5;
f = ( P / ( 1 + 1.6 * P ) - Q / ( 1 + 1.6 * Q ) );
g = ( R / ( 1 + 1.6 * R ) - P / ( 1 + 1.6 * P ) );
h = ( P / ( 1 + 1.6 * P ) - R / ( 1 + 1.6 * R ) );

beta_G = RTalpha * f;
beta_H = alpha_H * f;  % Enthalpy correction factor for reactants
beta_H2 = alpha_H * h; % Enthalpy correction factor for pKa's
beta_K = (alpha_K/2.303) * g;


function [ alpha_K, RTalpha, alpha_H ] = getAlphas( T )

alpha_K = 1.10708 - 1.54508e-3 * T + 5.95584e-6 * T^2;
alpha_H = -1.28466e-5 * T^2 + 9.90399e-8 * T^3;
RTalpha = 9.20483e-3 * T - 1.28467e-5 * T^2 + 4.95199e-8 * T^3; % (= alpha_K * RT)
