% This function checks whether the current parameter set is sufficient for
% the model. It will throw an error when something is missing and identify
% what is missing.
%
% function validateParameters( param, modelInfo, parx0, show )
%
% Mandatory parameters:
%   param         - The parameter vector to generate from
%   modelInfo     - modelInfo structure
%   parx0         - Specify 0 to check parameters and 
%                   1 to test initial conditions
%
% Optional input parameters:
%
%   show          - 1 for showing all the variables values, 0 for ignoring
%
% Output:
%   none
   
function [  ] = validateParameters( param, modelInfo, parx0 )
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.

    switch parx0
        case 0
            disp( 'Validating parameters' );
        case 1
            disp( 'Validating initial conditions' );
    end
    errz = 0;
    try
        if parx0 == 0
            parLength = length( fieldnames( modelInfo.ParID ) );
        end
        if parx0 == 1
            parLength = length( fieldnames( modelInfo.SVarID ) );
        end
    catch
        errz = 1;
        raiseError( 'Invalid modelInfo structure' );
    end
     
    parLen = length( param );
    
    if parLen > parLength
        disp( 'Warning: Parameter vector is too long' );
    end

    if parx0 == 0
        names = fieldnames( modelInfo.ParID );
        for a = 1 : parLength
            z = getfield( modelInfo.ParID, names{a} );
            if z > parLen
                disp( sprintf( '%s missing (index = %d)', names{a}, z ) );
                errz = 1;
            else
                if param( z ) == 0
                    disp( sprintf( 'Warning: Parameter %s (index = %d) is set to zero', names{a}, z ) );
                end
            end
        end
    end
    if parx0 == 1
        names = fieldnames( modelInfo.SVarID );                
        for a = 1 : parLength
            z = getfield( modelInfo.SVarID, names{a} );
            if z > parLen
                disp( sprintf( 'FATAL  :%s missing (index = %d)', names{a}, z ) );
                errz = 1;
            else
                if param( z ) == 0
                    disp( sprintf( 'Warning: Parameter %s (index = %d) is set to zero', names{a}, z ) );
                end                
            end
        end
    end

    if errz == 1
        raiseError( 'FATAL: Parameters missing!\n' );
        return;
    end
    
    function raiseError( errz );
    ME = MException('VerifyInput:Error', errz);
    throw(ME);
    